==> miria-monitor-api-0.0.3-20180822.085031-9-sources.jar: cn/com/duiba/miria/monitor/api/entity/GroupDingTalk.java <==
package cn.com.duiba.miria.monitor.api.entity;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

@Table(name = "tb_group_dingtalk")
public class GroupDingTalk {
    /**
     * 自增id
     */
    @Id
    private Long id;

    /**
     * 管理叮叮机器人主键id,来源：dingtalk.id
     */
    @Column(name = "dingtalk_id")
    private Long dingtalkId;

    /**
     * 应用id
     */
    @Column(name = "group_id")
    private Long groupId;

    /**
     * 创建时间
     */
    @Column(name = "gmt_create")
    private Date gmtCreate;

    /**
     * 修改时间
     */
    @Column(name = "gmt_modified")
    private Date gmtModified;

    /**
     * 获取自增id
     *
     * @return id - 自增id
     */
    public Long getId() {
        return id;
    }

    /**
     * 设置自增id
     *
     * @param id 自增id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 获取管理叮叮机器人主键id,来源：dingtalk.id
     *
     * @return dingtalk_id - 管理叮叮机器人主键id,来源：dingtalk.id
     */
    public Long getDingtalkId() {
        return dingtalkId;
    }

    /**
     * 设置管理叮叮机器人主键id,来源：dingtalk.id
     *
     * @param dingtalkId 管理叮叮机器人主键id,来源：dingtalk.id
     */
    public void setDingtalkId(Long dingtalkId) {
        this.dingtalkId = dingtalkId;
    }

    /**
     * 获取应用id
     *
     * @return group_id - 应用id
     */
    public Long getGroupId() {
        return groupId;
    }

    /**
     * 设置应用id
     *
     * @param groupId 应用id
     */
    public void setGroupId(Long groupId) {
        this.groupId = groupId;
    }

    /**
     * 获取创建时间
     *
     * @return gmt_create - 创建时间
     */
    public Date getGmtCreate() {
        return gmtCreate;
    }

    /**
     * 设置创建时间
     *
     * @param gmtCreate 创建时间
     */
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    /**
     * 获取修改时间
     *
     * @return gmt_modified - 修改时间
     */
    public Date getGmtModified() {
        return gmtModified;
    }

    /**
     * 设置修改时间
     *
     * @param gmtModified 修改时间
     */
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> miria-monitor-api-1.0.4-sources.jar: cn/com/duiba/miria/monitor/api/entity/GroupDingTalk.java <==
package cn.com.duiba.miria.monitor.api.entity;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

@Table(name = "tb_group_dingtalk")
public class GroupDingTalk implements Serializable {
    /**
     * 自增id
     */
    @Id
    private Long id;

    /**
     * 管理叮叮机器人主键id,来源：dingtalk.id
     */
    @Column(name = "dingtalk_id")
    private Long dingtalkId;

    /**
     * 应用id
     */
    @Column(name = "group_id")
    private Long groupId;

    /**
     * 创建时间
     */
    @Column(name = "gmt_create")
    private Date gmtCreate;

    /**
     * 修改时间
     */
    @Column(name = "gmt_modified")
    private Date gmtModified;

    /**
     * 获取自增id
     *
     * @return id - 自增id
     */
    public Long getId() {
        return id;
    }

    /**
     * 设置自增id
     *
     * @param id 自增id
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 获取管理叮叮机器人主键id,来源：dingtalk.id
     *
     * @return dingtalk_id - 管理叮叮机器人主键id,来源：dingtalk.id
     */
    public Long getDingtalkId() {
        return dingtalkId;
    }

    /**
     * 设置管理叮叮机器人主键id,来源：dingtalk.id
     *
     * @param dingtalkId 管理叮叮机器人主键id,来源：dingtalk.id
     */
    public void setDingtalkId(Long dingtalkId) {
        this.dingtalkId = dingtalkId;
    }

    /**
     * 获取应用id
     *
     * @return group_id - 应用id
     */
    public Long getGroupId() {
        return groupId;
    }

    /**
     * 设置应用id
     *
     * @param groupId 应用id
     */
    public void setGroupId(Long groupId) {
        this.groupId = groupId;
    }

    /**
     * 获取创建时间
     *
     * @return gmt_create - 创建时间
     */
    public Date getGmtCreate() {
        return gmtCreate;
    }

    /**
     * 设置创建时间
     *
     * @param gmtCreate 创建时间
     */
    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    /**
     * 获取修改时间
     *
     * @return gmt_modified - 修改时间
     */
    public Date getGmtModified() {
        return gmtModified;
    }

    /**
     * 设置修改时间
     *
     * @param gmtModified 修改时间
     */
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
